@@ -8,7 +8,7 @@ package App::sourcepan;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use CPAN;
 use File::Basename qw( basename );
@@ -145,9 +145,12 @@ sub vc_init_bzr
    # In a subprocess
    chdir $dirname or die "Cannot chdir $dirname - $!";
 
-   IPC::Run::run( [ "bzr", "init" ] ) or die "Unable to 'bzr init' ($?)\n";
-   IPC::Run::run( [ "bzr", "add", "." ] ) or die "Unable to 'bzr add ($?)\n";
-   IPC::Run::run( [ "bzr", "commit", "-m", "Imported $opts{id}" ] ) or die "Unable to 'bzr commit' ($?)\n";
+   system( "bzr", "init" ) == 0
+      or die "Unable to 'bzr init' ($?)\n";
+   system( "bzr", "add", "." ) == 0
+      or die "Unable to 'bzr add ($?)\n";
+   system( "bzr", "commit", "-m", "Imported $opts{id}" ) == 0
+      or die "Unable to 'bzr commit' ($?)\n";
 }
 
 sub vc_init_git
@@ -160,9 +163,12 @@ sub vc_init_git
    # In a subprocess
    chdir $dirname or die "Cannot chdir $dirname - $!";
 
-   IPC::Run::run( [ "git", "init" ] ) or die "Unable to 'git init' ($?)\n";
-   IPC::Run::run( [ "git", "add", "." ] ) or die "Unable to 'git add ($?)\n";
-   IPC::Run::run( [ "git", "commit", "-m", "Imported $opts{id}" ] ) or die "Unable to 'git commit' ($?)\n";
+   system( "git", "init" ) == 0
+      or die "Unable to 'git init' ($?)\n";
+   system( "git", "add", "." ) == 0
+      or die "Unable to 'git add ($?)\n";
+   system( "git", "commit", "-m", "Imported $opts{id}" ) == 0
+      or die "Unable to 'git commit' ($?)\n";
 }
 
 =head1 AUTHOR
